@@ -21,6 +21,7 @@ from openstack.compute.v2 import server as _server
 from openstack.compute.v2 import server_group as _server_group
 from openstack.compute.v2 import server_interface as _server_interface
 from openstack.compute.v2 import server_ip
+from openstack.compute.v2 import service as _service
 from openstack import proxy2
 from openstack import resource2
 
@@ -230,7 +231,7 @@ class Proxy(proxy2.BaseProxy):
                        :class:`~openstack.compute.v2.image.Image` or
                        :class:`~openstack.compute.v2.image.ImageDetail`
                        instance.
-        :param list keys: The keys to delete.
+        :param keys: The keys to delete.
 
         :rtype: ``None``
         """
@@ -322,7 +323,7 @@ class Proxy(proxy2.BaseProxy):
         """
         return self._create(_server.Server, **attrs)
 
-    def delete_server(self, server, ignore_missing=True):
+    def delete_server(self, server, ignore_missing=True, force=False):
         """Delete a server
 
         :param server: The value can be either the ID of a server or a
@@ -331,11 +332,17 @@ class Proxy(proxy2.BaseProxy):
                     :class:`~openstack.exceptions.ResourceNotFound` will be
                     raised when the server does not exist.
                     When set to ``True``, no exception will be set when
-                    attempting to delete a nonexistent server.
+                    attempting to delete a nonexistent server
+        :param bool force: When set to ``True``, the server deletion will be
+                           forced immediatly.
 
         :returns: ``None``
         """
-        self._delete(_server.Server, server, ignore_missing=ignore_missing)
+        if force:
+            server = self._get_resource(_server.Server, server)
+            server.force_delete(self.session)
+        else:
+            self._delete(_server.Server, server, ignore_missing=ignore_missing)
 
     def find_server(self, name_or_id, ignore_missing=True):
         """Find a single server
@@ -428,6 +435,19 @@ class Proxy(proxy2.BaseProxy):
         server = self._get_resource(_server.Server, server)
         server.change_password(self.session, new_password)
 
+    def reset_server_state(self, server, state):
+        """Reset the state of server
+
+        :param server: The server can be either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`.
+        :param state: The state of the server to be set, `active` or
+                      `error` are valid.
+
+        :returns: None
+        """
+        res = self._get_base_resource(server, _server.Server)
+        res.reset_state(self.session, state)
+
     def reboot_server(self, server, reboot_type):
         """Reboot a server
 
@@ -458,10 +478,10 @@ class Proxy(proxy2.BaseProxy):
                                 *Default: None*
         :param dict metadata: A dictionary of metadata to rebuild with.
                                *Default: None*
-        :param list personality: A list of dictionaries, each including a
-                                 **path** and **contents** key, to be injected
-                                 into the rebuilt server at launch.
-                                 *Default: None*
+        :param personality: A list of dictionaries, each including a
+                            **path** and **contents** key, to be injected
+                            into the rebuilt server at launch.
+                            *Default: None*
 
         :returns: The rebuilt :class:`~openstack.compute.v2.server.Server`
                   instance.
@@ -548,6 +568,211 @@ class Proxy(proxy2.BaseProxy):
         security_group_id = resource2.Resource._get_id(security_group)
         server.remove_security_group(self.session, security_group_id)
 
+    def add_fixed_ip_to_server(self, server, network_id):
+        """Adds a fixed IP address to a server instance.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param network_id: The ID of the network from which a fixed IP address
+                           is about to be allocated.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.add_fixed_ip(self.session, network_id)
+
+    def remove_fixed_ip_from_server(self, server, address):
+        """Removes a fixed IP address from a server instance.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param address: The fixed IP address to be disassociated from the
+                        server.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.remove_fixed_ip(self.session, address)
+
+    def add_floating_ip_to_server(self, server, address, fixed_address=None):
+        """Adds a floating IP address to a server instance.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param address: The floating IP address to be added to the server.
+        :param fixed_address: The fixed IP address to be associated with the
+                              floating IP address. Used when the server is
+                              connected to multiple networks.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.add_floating_ip(self.session, address,
+                               fixed_address=fixed_address)
+
+    def remove_floating_ip_from_server(self, server, address):
+        """Removes a floating IP address from a server instance.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param address: The floating IP address to be disassociated from the
+                        server.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.remove_floating_ip(self.session, address)
+
+    def pause_server(self, server):
+        """Pauses a server and changes its status to ``PAUSED``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.pause(self.session)
+
+    def unpause_server(self, server):
+        """Unpauses a paused server and changes its status to ``ACTIVE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.unpause(self.session)
+
+    def suspend_server(self, server):
+        """Suspends a server and changes its status to ``SUSPENDED``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.suspend(self.session)
+
+    def resume_server(self, server):
+        """Resumes a suspended server and changes its status to ``ACTIVE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.resume(self.session)
+
+    def lock_server(self, server):
+        """Locks a server.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.lock(self.session)
+
+    def unlock_server(self, server):
+        """Unlocks a locked server.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.unlock(self.session)
+
+    def rescue_server(self, server, admin_pass=None, image_ref=None):
+        """Puts a server in rescue mode and changes it status to ``RESCUE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param admin_pass: The password for the rescued server. If you omit
+                           this parameter, the operation generates a new
+                           password.
+        :param image_ref: The image reference to use to rescue your server.
+                          This can be the image ID or its full URL. If you
+                          omit this parameter, the base image reference will
+                          be used.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.rescue(self.session, admin_pass=admin_pass, image_ref=image_ref)
+
+    def unrescue_server(self, server):
+        """Unrescues a server and changes its status to ``ACTIVE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.unrescue(self.session)
+
+    def evacuate_server(self, server, host=None, admin_pass=None, force=None):
+        """Evacuates a server from a failed host to a new host.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param host: An optional parameter specifying the name or ID of the
+                     host to which the server is evacuated.
+        :param admin_pass: An optional parameter specifying the administrative
+                           password to access the evacuated or rebuilt server.
+        :param force: Force an evacuation by not verifying the provided
+                      destination host by the scheduler. (New in API version
+                      2.29).
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.evacuate(self.session, host=host, admin_pass=admin_pass,
+                        force=force)
+
+    def start_server(self, server):
+        """Starts a stopped server and changes its state to ``ACTIVE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.start(self.session)
+
+    def stop_server(self, server):
+        """Stops a running server and changes its state to ``SHUTOFF``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.stop(self.session)
+
+    def shelve_server(self, server):
+        """Shelves a server.
+
+        All associated data and resources are kept but anything still in
+        memory is not retained. Policy defaults enable only users with
+        administrative role or the owner of the server to perform this
+        operation. Cloud provides could change this permission though.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.shelve(self.session)
+
+    def unshelve_server(self, server):
+        """Unselves or restores a shelved server.
+
+        Policy defaults enable only users with administrative role or the
+        owner of the server to perform this operation. Cloud provides could
+        change this permission though.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.unshelve(self.session)
+
     def wait_for_server(self, server, status='ACTIVE', failures=['ERROR'],
                         interval=2, wait=120):
         return resource2.wait_for_status(self.session, server, status,
@@ -716,7 +941,7 @@ class Proxy(proxy2.BaseProxy):
                        :class:`~openstack.compute.v2.server.Server` or
                        :class:`~openstack.compute.v2.server.ServerDetail`
                        instance.
-        :param list keys: The keys to delete
+        :param keys: The keys to delete
 
         :rtype: ``None``
         """
@@ -828,3 +1053,69 @@ class Proxy(proxy2.BaseProxy):
                  when no resource can be found.
         """
         return self._get(_hypervisor.Hypervisor, hypervisor)
+
+    def get_service(self, service):
+        """Get a single service
+
+        :param service: The value can be the ID of a serivce or a
+               :class:`~openstack.compute.v2.service.Service`
+               instance.
+
+        :returns:
+            A :class:`~openstack.compute.v2.serivce.Service` object.
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        return self._get(_service.Service, service)
+
+    def force_service_down(self, service, host, binary):
+        """Force a service down
+
+        :param service: Either the ID of a service or a
+                       :class:`~openstack.compute.v2.server.Service` instance.
+        :param str host: The host where service runs.
+        :param str binary: The name of service.
+
+        :returns: None
+        """
+        service = self._get_resource(_service.Service, service)
+        service.force_down(self.session, host, binary)
+
+    def disable_service(self, service, host, binary, disabled_reason=None):
+        """Disable a service
+
+        :param service: Either the ID of a service or a
+                       :class:`~openstack.compute.v2.server.Service` instance.
+        :param str host: The host where service runs.
+        :param str binary: The name of service.
+        :param str disabled_reason: The reason of force down a service.
+
+        :returns: None
+        """
+        service = self._get_resource(_service.Service, service)
+        service.disable(self.session,
+                        host, binary,
+                        disabled_reason)
+
+    def enable_service(self, service, host, binary):
+        """Enable a service
+
+        :param service: Either the ID of a service or a
+                       :class:`~openstack.compute.v2.server.Service` instance.
+        :param str host: The host where service runs.
+        :param str binary: The name of service.
+
+
+        :returns: None
+        """
+        service = self._get_resource(_service.Service, service)
+        service.enable(self.session, host, binary)
+
+    def services(self):
+        """Return a generator of service
+
+        :returns: A generator of service
+        :rtype: class: `~openstack.compute.v2.service.Service`
+        """
+
+        return self._list(_service.Service, paginated=False)
